@@ -25,6 +25,8 @@ def get_probe_runner_host():
         return "https://proberunner.internal.hdfc-beta.zetaapps.in"
     if env.lower() == 'lz':
         return "https://proberunner.hdfclz.zetaapps.in"
+    if env.lower() == 'ow':
+        return "https://proberunner.internal.olympus-world.zetaapps.in"
     else:
         raise ValueError("Incorrect argument passed as env : " + env)
 
